@@ -18,6 +18,7 @@ IPROTO_SERVER_UUID = 0x24
 IPROTO_CLUSTER_UUID = 0x25
 IPROTO_VCLOCK = 0x26
 IPROTO_EXPR = 0x27
+IPROTO_OPS = 0x28
 IPROTO_DATA = 0x30
 IPROTO_ERROR = 0x31
 
@@ -32,16 +33,19 @@ REQUEST_TYPE_DELETE = 5
 REQUEST_TYPE_CALL = 6
 REQUEST_TYPE_AUTHENTICATE = 7
 REQUEST_TYPE_EVAL = 8
+REQUEST_TYPE_UPSERT = 9
 REQUEST_TYPE_PING = 64
 REQUEST_TYPE_JOIN = 65
 REQUEST_TYPE_SUBSCRIBE = 66
 REQUEST_TYPE_ERROR = 1 << 15
 
-
 SPACE_SCHEMA = 272
 SPACE_SPACE = 280
 SPACE_INDEX = 288
 SPACE_FUNC = 296
+SPACE_VSPACE = 281
+SPACE_VINDEX = 289
+SPACE_VFUNC = 297
 SPACE_USER = 304
 SPACE_PRIV = 312
 SPACE_CLUSTER = 320
